@@ -408,7 +408,7 @@ class LocalConfig(object):
             if validate:
                 self.validate()
         elif xmlPath is not None:
-            with open(xmlPath) as f:
+            with open(xmlPath) as f:  # pylint: disable=unspecified-encoding
                 xmlData = f.read()
             self._parseXmlData(xmlData)
             if validate:
@@ -887,7 +887,7 @@ def _encryptStagingDir(config, local, stagingDir, encryptedDir):
         if os.path.isfile(cleartext):
             encrypted = "%s%s" % (encryptedDir, cleartext.replace(stagingDir, ""))
             if int(os.stat(cleartext).st_size) == 0:
-                with open(encrypted, "a") as f:
+                with open(encrypted, "a") as f:  # pylint: disable=unspecified-encoding
                     f.close()  # don't bother encrypting empty files
             else:
                 actualCommand = local.amazons3.encryptCommand.replace("${input}", cleartext).replace("${output}", encrypted)
