@@ -106,7 +106,7 @@ from CedarBackup3.testutil import (
     removedir,
     setupOverrides,
 )
-from CedarBackup3.util import executeCommand
+from CedarBackup3.util import executeCommand, pathJoin
 from CedarBackup3.writers.util import IsoImage, validateDriveSpeed, validateScsiId
 
 #######################################################################
@@ -995,7 +995,7 @@ class TestIsoImage(unittest.TestCase):
         isoImage = IsoImage(graftPoint="p")
         self.assertEqual({}, isoImage.entries)
         isoImage.addEntry(dir1)
-        self.assertEqual({dir1: os.path.join("p", "tree9")}, isoImage.entries)
+        self.assertEqual({dir1: pathJoin("p", "tree9")}, isoImage.entries)
 
     def testAddEntry_011(self):
         """
@@ -1006,7 +1006,7 @@ class TestIsoImage(unittest.TestCase):
         isoImage = IsoImage()
         self.assertEqual({}, isoImage.entries)
         isoImage.addEntry(dir1, graftPoint="s")
-        self.assertEqual({dir1: os.path.join("s", "tree9")}, isoImage.entries)
+        self.assertEqual({dir1: pathJoin("s", "tree9")}, isoImage.entries)
 
     def testAddEntry_012(self):
         """
@@ -1233,7 +1233,7 @@ class TestIsoImage(unittest.TestCase):
         fsList.addDirContents(mountPath)
         self.assertEqual(2, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "dir002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "dir002") in fsList)
 
     @unittest.skipUnless(runAllTests(), "Limited test suite")
     def testWriteImage_003(self):
@@ -1251,8 +1251,8 @@ class TestIsoImage(unittest.TestCase):
         fsList.addDirContents(mountPath)
         self.assertEqual(3, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "base") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir002") in fsList)
 
     @unittest.skipUnless(runAllTests(), "Limited test suite")
     def testWriteImage_004(self):
@@ -1271,15 +1271,15 @@ class TestIsoImage(unittest.TestCase):
         fsList.addDirContents(mountPath)
         self.assertEqual(10, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "dir002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "dir002", "file001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "dir002", "file002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "dir002", "link001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "dir002", "link002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "dir002", "link003") in fsList)
-        self.assertTrue(os.path.join(mountPath, "dir002", "link004") in fsList)
-        self.assertTrue(os.path.join(mountPath, "dir002", "dir001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "dir002", "dir002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "dir002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "dir002", "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "dir002", "file002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "dir002", "link001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "dir002", "link002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "dir002", "link003") in fsList)
+        self.assertTrue(pathJoin(mountPath, "dir002", "link004") in fsList)
+        self.assertTrue(pathJoin(mountPath, "dir002", "dir001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "dir002", "dir002") in fsList)
 
     @unittest.skipUnless(runAllTests(), "Limited test suite")
     def testWriteImage_005(self):
@@ -1291,24 +1291,24 @@ class TestIsoImage(unittest.TestCase):
         isoImage = IsoImage()
         dir1 = self.buildPath(["tree9", "dir002"])
         imagePath = self.buildPath(["image.iso"])
-        isoImage.addEntry(dir1, graftPoint=os.path.join("something", "else"))
+        isoImage.addEntry(dir1, graftPoint=pathJoin("something", "else"))
         isoImage.writeImage(imagePath)
         mountPath = self.mountImage(imagePath)
         fsList = FilesystemList()
         fsList.addDirContents(mountPath)
         self.assertEqual(12, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "something") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "else") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "else", "dir002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "else", "dir002", "file001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "else", "dir002", "file002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "else", "dir002", "link001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "else", "dir002", "link002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "else", "dir002", "link003") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "else", "dir002", "link004") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "else", "dir002", "dir001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "else", "dir002", "dir002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "else") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "else", "dir002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "else", "dir002", "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "else", "dir002", "file002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "else", "dir002", "link001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "else", "dir002", "link002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "else", "dir002", "link003") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "else", "dir002", "link004") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "else", "dir002", "dir001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "else", "dir002", "dir002") in fsList)
 
     @unittest.skipUnless(runAllTests(), "Limited test suite")
     def testWriteImage_006(self):
@@ -1326,7 +1326,7 @@ class TestIsoImage(unittest.TestCase):
         fsList.addDirContents(mountPath)
         self.assertEqual(2, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "file001") in fsList)
 
     @unittest.skipUnless(runAllTests(), "Limited test suite")
     def testWriteImage_007(self):
@@ -1344,8 +1344,8 @@ class TestIsoImage(unittest.TestCase):
         fsList.addDirContents(mountPath)
         self.assertEqual(3, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "point") in fsList)
-        self.assertTrue(os.path.join(mountPath, "point", "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "point") in fsList)
+        self.assertTrue(pathJoin(mountPath, "point", "file001") in fsList)
 
     @unittest.skipUnless(runAllTests(), "Limited test suite")
     def testWriteImage_008(self):
@@ -1366,8 +1366,8 @@ class TestIsoImage(unittest.TestCase):
         fsList.addDirContents(mountPath)
         self.assertEqual(3, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "file001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "dir002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "dir002") in fsList)
 
     @unittest.skipUnless(runAllTests(), "Limited test suite")
     def testWriteImage_009(self):
@@ -1388,10 +1388,10 @@ class TestIsoImage(unittest.TestCase):
         fsList.addDirContents(mountPath)
         self.assertEqual(5, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "other") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base") in fsList)
-        self.assertTrue(os.path.join(mountPath, "other", "file001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "other") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base") in fsList)
+        self.assertTrue(pathJoin(mountPath, "other", "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir002") in fsList)
 
     @unittest.skipUnless(runAllTests(), "Limited test suite")
     def testWriteImage_010(self):
@@ -1412,16 +1412,16 @@ class TestIsoImage(unittest.TestCase):
         fsList.addDirContents(mountPath)
         self.assertEqual(11, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "base") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "file001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir001", "file001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir001", "file002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir001", "link001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir001", "link002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir001", "link003") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir001", "dir001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir001", "dir002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir001", "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir001", "file002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir001", "link001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir001", "link002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir001", "link003") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir001", "dir001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir001", "dir002") in fsList)
 
     @unittest.skipUnless(runAllTests(), "Limited test suite")
     def testWriteImage_011(self):
@@ -1444,18 +1444,18 @@ class TestIsoImage(unittest.TestCase):
         fsList.addDirContents(mountPath)
         self.assertEqual(13, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "base") in fsList)
-        self.assertTrue(os.path.join(mountPath, "other") in fsList)
-        self.assertTrue(os.path.join(mountPath, "file001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "other", "file002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir001", "file001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir001", "file002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir001", "link001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir001", "link002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir001", "link003") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir001", "dir001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir001", "dir002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base") in fsList)
+        self.assertTrue(pathJoin(mountPath, "other") in fsList)
+        self.assertTrue(pathJoin(mountPath, "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "other", "file002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir001", "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir001", "file002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir001", "link001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir001", "link002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir001", "link003") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir001", "dir001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir001", "dir002") in fsList)
 
     @unittest.skipUnless(runAllTests(), "Limited test suite")
     def testWriteImage_012(self):
@@ -1473,29 +1473,29 @@ class TestIsoImage(unittest.TestCase):
         fsList.addDirContents(mountPath)
         self.assertEqual(24, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "something") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "file001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "file002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "link001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "link002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "dir001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "dir001", "file001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "dir001", "file002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "dir001", "link001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "dir001", "link002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "dir001", "link003") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "dir001", "dir001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "dir001", "dir002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "dir002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "dir002", "file001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "dir002", "file002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "dir002", "link001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "dir002", "link002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "dir002", "link003") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "dir002", "link004") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "dir002", "dir001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "tree9", "dir002", "dir002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "file002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "link001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "link002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "dir001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "dir001", "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "dir001", "file002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "dir001", "link001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "dir001", "link002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "dir001", "link003") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "dir001", "dir001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "dir001", "dir002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "dir002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "dir002", "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "dir002", "file002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "dir002", "link001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "dir002", "link002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "dir002", "link003") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "dir002", "link004") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "dir002", "dir001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "tree9", "dir002", "dir002") in fsList)
 
     @unittest.skipUnless(runAllTests(), "Limited test suite")
     def testWriteImage_013(self):
@@ -1532,7 +1532,7 @@ class TestIsoImage(unittest.TestCase):
         fsList.addDirContents(mountPath)
         self.assertEqual(2, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "base") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base") in fsList)
 
     @unittest.skipUnless(runAllTests(), "Limited test suite")
     def testWriteImage_015(self):
@@ -1551,14 +1551,14 @@ class TestIsoImage(unittest.TestCase):
         fsList.addDirContents(mountPath)
         self.assertEqual(9, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "file001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "file002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "link001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "link002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "link003") in fsList)
-        self.assertTrue(os.path.join(mountPath, "link004") in fsList)
-        self.assertTrue(os.path.join(mountPath, "dir001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "dir002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "file002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "link001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "link002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "link003") in fsList)
+        self.assertTrue(pathJoin(mountPath, "link004") in fsList)
+        self.assertTrue(pathJoin(mountPath, "dir001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "dir002") in fsList)
 
     @unittest.skipUnless(runAllTests(), "Limited test suite")
     def testWriteImage_016(self):
@@ -1570,23 +1570,23 @@ class TestIsoImage(unittest.TestCase):
         isoImage = IsoImage()
         dir1 = self.buildPath(["tree9", "dir002"])
         imagePath = self.buildPath(["image.iso"])
-        isoImage.addEntry(dir1, graftPoint=os.path.join("something", "else"), contentsOnly=True)
+        isoImage.addEntry(dir1, graftPoint=pathJoin("something", "else"), contentsOnly=True)
         isoImage.writeImage(imagePath)
         mountPath = self.mountImage(imagePath)
         fsList = FilesystemList()
         fsList.addDirContents(mountPath)
         self.assertEqual(11, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "something") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "else") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "else", "file001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "else", "file002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "else", "link001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "else", "link002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "else", "link003") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "else", "link004") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "else", "dir001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "else", "dir002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "else") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "else", "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "else", "file002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "else", "link001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "else", "link002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "else", "link003") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "else", "link004") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "else", "dir001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "else", "dir002") in fsList)
 
     @unittest.skipUnless(runAllTests(), "Limited test suite")
     def testWriteImage_017(self):
@@ -1605,7 +1605,7 @@ class TestIsoImage(unittest.TestCase):
         fsList.addDirContents(mountPath)
         self.assertEqual(2, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "file001") in fsList)
 
     @unittest.skipUnless(runAllTests(), "Limited test suite")
     def testWriteImage_018(self):
@@ -1624,8 +1624,8 @@ class TestIsoImage(unittest.TestCase):
         fsList.addDirContents(mountPath)
         self.assertEqual(3, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "point") in fsList)
-        self.assertTrue(os.path.join(mountPath, "point", "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "point") in fsList)
+        self.assertTrue(pathJoin(mountPath, "point", "file001") in fsList)
 
     @unittest.skipUnless(runAllTests(), "Limited test suite")
     def testWriteImage_019(self):
@@ -1646,7 +1646,7 @@ class TestIsoImage(unittest.TestCase):
         fsList.addDirContents(mountPath)
         self.assertEqual(2, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "file001") in fsList)
 
     @unittest.skipUnless(runAllTests(), "Limited test suite")
     def testWriteImage_020(self):
@@ -1667,9 +1667,9 @@ class TestIsoImage(unittest.TestCase):
         fsList.addDirContents(mountPath)
         self.assertEqual(4, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "other") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base") in fsList)
-        self.assertTrue(os.path.join(mountPath, "other", "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "other") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base") in fsList)
+        self.assertTrue(pathJoin(mountPath, "other", "file001") in fsList)
 
     @unittest.skipUnless(runAllTests(), "Limited test suite")
     def testWriteImage_021(self):
@@ -1707,17 +1707,17 @@ class TestIsoImage(unittest.TestCase):
         fsList.addDirContents(mountPath)
         self.assertEqual(12, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "base") in fsList)
-        self.assertTrue(os.path.join(mountPath, "other") in fsList)
-        self.assertTrue(os.path.join(mountPath, "file001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "other", "file002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "file001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "file002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "link001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "link002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "link003") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "base", "dir002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base") in fsList)
+        self.assertTrue(pathJoin(mountPath, "other") in fsList)
+        self.assertTrue(pathJoin(mountPath, "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "other", "file002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "file002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "link001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "link002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "link003") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "base", "dir002") in fsList)
 
     @unittest.skipUnless(runAllTests(), "Limited test suite")
     def testWriteImage_023(self):
@@ -1736,25 +1736,25 @@ class TestIsoImage(unittest.TestCase):
         fsList.addDirContents(mountPath)
         self.assertEqual(23, len(fsList))
         self.assertTrue(mountPath in fsList)
-        self.assertTrue(os.path.join(mountPath, "something") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "file001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "file002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "link001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "link002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "dir001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "dir001", "file001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "dir001", "file002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "dir001", "link001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "dir001", "link002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "dir001", "link003") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "dir001", "dir001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "dir001", "dir002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "dir002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "dir002", "file001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "dir002", "file002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "dir002", "link001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "dir002", "link002") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "dir002", "link003") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "dir002", "link004") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "dir002", "dir001") in fsList)
-        self.assertTrue(os.path.join(mountPath, "something", "dir002", "dir002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "file002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "link001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "link002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "dir001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "dir001", "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "dir001", "file002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "dir001", "link001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "dir001", "link002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "dir001", "link003") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "dir001", "dir001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "dir001", "dir002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "dir002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "dir002", "file001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "dir002", "file002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "dir002", "link001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "dir002", "link002") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "dir002", "link003") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "dir002", "link004") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "dir002", "dir001") in fsList)
+        self.assertTrue(pathJoin(mountPath, "something", "dir002", "dir002") in fsList)
